@@ -107,9 +107,10 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument)
     return true;
 }
 
-bool SKGFilePlugin::processArguments(const QStringList& iArgument)
+QStringList SKGFilePlugin::processArguments(const QStringList& iArgument)
 {
     SKGTRACEINFUNC(10);
+    QStringList output = iArgument;
     int nbArg = iArgument.count();
     int openMode = 1;  // 0=no open, 1=open last opened if settings set, 2=new document
     if (nbArg) {
@@ -125,7 +126,7 @@ bool SKGFilePlugin::processArguments(const QStringList& iArgument)
                 }
             }
             Q_EMIT loadFile(QUrl::fromLocalFile(filename));
-
+            output.pop_back();
             openMode = 0;
         }
     }
@@ -150,7 +151,7 @@ bool SKGFilePlugin::processArguments(const QStringList& iArgument)
             openMode = 2;
         }
 
-        if (openMode == 2) {
+        if (openMode == 2 && m_currentDocument->getMainDatabase() == nullptr) {
             onNew();
         }
     }
@@ -158,7 +159,7 @@ bool SKGFilePlugin::processArguments(const QStringList& iArgument)
     // To be sure that the document has the right parameters
     savePreferences();
 
-    return (openMode == 0);
+    return output;
 }
 
 QWidget* SKGFilePlugin::getPreferenceWidget()
