@@ -337,7 +337,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
             if (!err && operationObj.getComment().isEmpty()) {
                 err = operationObj.setComment(suboperation.attribute(QStringLiteral("memo")));
             }
-            IFOKDO(err, operationObj.setNumber(SKGServices::stringToInt(suboperation.attribute(QStringLiteral("number")))))
+            IFOKDO(err, operationObj.setNumber(suboperation.attribute(QStringLiteral("number"))))
 
             // Set state
             if (operationObj.getStatus() == SKGOperationObject::NONE) {
@@ -1614,7 +1614,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
         split.setAttribute(QStringLiteral("shares"), SKGImportPluginKmy::kmyValue(val2));
         split.setAttribute(QStringLiteral("action"), QStringLiteral(""));
         split.setAttribute(QStringLiteral("bankid"), QStringLiteral(""));
-        split.setAttribute(QStringLiteral("number"), SKGServices::intToString(iOperation.getNumber()));
+        split.setAttribute(QStringLiteral("number"), iOperation.getNumber());
         split.setAttribute(QStringLiteral("reconcileflag"), reconcileflag);
         split.setAttribute(QStringLiteral("memo"), iOperation.getComment());
         QString originalAmount = iOperation.getProperty(QStringLiteral("SKG_OP_ORIGINAL_AMOUNT"));
@@ -1643,7 +1643,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
             split2.setAttribute(QStringLiteral("shares"), SKGImportPluginKmy::kmyValue(SKGServices::stringToDouble(obj2.getAttribute(QStringLiteral("f_QUANTITY")))));
             split2.setAttribute(QStringLiteral("action"), QStringLiteral(""));
             split2.setAttribute(QStringLiteral("bankid"), QStringLiteral(""));
-            split2.setAttribute(QStringLiteral("number"), SKGServices::intToString(obj2.getNumber()));
+            split2.setAttribute(QStringLiteral("number"), obj2.getNumber());
             split2.setAttribute(QStringLiteral("reconcileflag"), reconcileflag2);
             split2.setAttribute(QStringLiteral("memo"), obj2.getComment());
             split2.setAttribute(QStringLiteral("value"), SKGImportPluginKmy::kmyValue(val2));
@@ -1668,7 +1668,7 @@ SKGError SKGImportPluginKmy::exportOperation(const SKGOperationObject& iOperatio
                 split2.setAttribute(QStringLiteral("shares"), shape3);
                 split2.setAttribute(QStringLiteral("action"), QStringLiteral(""));
                 split2.setAttribute(QStringLiteral("bankid"), QStringLiteral(""));
-                split2.setAttribute(QStringLiteral("number"), SKGServices::intToString(iOperation.getNumber()));
+                split2.setAttribute(QStringLiteral("number"), iOperation.getNumber());
                 split2.setAttribute(QStringLiteral("reconcileflag"), reconcileflag);
                 split2.setAttribute(QStringLiteral("memo"), subop.getComment());
                 split2.setAttribute(QStringLiteral("value"), shape3);
