@@ -86,6 +86,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument)
     }
 
     m_currentBankDocument->setComputeBalances(skgoperation_settings::computeBalances());
+    m_currentBankDocument->addEndOfTransactionCheck(SKGOperationPlugin::checkReconciliation);
 
     setComponentName(QStringLiteral("skrooge_operation"), title());
     setXMLFile(QStringLiteral("skrooge_operation.rc"));
@@ -374,6 +375,31 @@ void SKGOperationPlugin::refresh()
     }
 }
 
+SKGError SKGOperationPlugin::checkReconciliation(SKGDocument* iDocument)
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(5, err);
+    if (iDocument && SKGMainPanel::getMainPanel() && skgoperation_settings::broken_reconciliation() > QStringLiteral("0")) {
+        // Check the reconciliation for all opened account
+        SKGObjectBase::SKGListSKGObjectBase accounts;
+        iDocument->getObjects(QStringLiteral("v_account"), QStringLiteral("t_close='N' AND f_reconciliationbalance!=''"), accounts);
+        for (const auto& account : accounts) {
+            SKGAccountObject a(account);
+            auto soluces = a.getPossibleReconciliations(SKGServices::stringToDouble(account.getAttribute(QStringLiteral("f_reconciliationbalance"))), false);
+            if (soluces.isEmpty()) {
+                if (skgoperation_settings::broken_reconciliation() == QStringLiteral("1")) {
+                    iDocument->sendMessage(i18nc("Warning message", "The previous reconciliation of '%1' has been broken by this action or a previous one.", a.getDisplayName()), SKGDocument::Warning, QStringLiteral("skg://edit_undo"));
+                } else {
+                    auto msg = i18nc("Warning message", "This action would break the previous reconciliation of '%1', so it is cancelled.", a.getDisplayName());
+                    iDocument->sendMessage(msg, SKGDocument::Error);
+                    return err = SKGError(ERR_ABORT, msg);
+                }
+            }
+        }
+    }
+    return err;
+}
+
 int SKGOperationPlugin::getNbDashboardWidgets()
 {
     return 2;
