@@ -213,7 +213,7 @@ void SKGPayeePluginWidget::onAddPayee()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 void SKGPayeePluginWidget::onModifyPayee()
@@ -228,31 +228,51 @@ void SKGPayeePluginWidget::onModifyPayee()
 
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Payee update"), err, nb);
-        // Is it a massive modification of payees to merge them ?
-        if (nb > 1 && ui.kNameInput->text() != NOUPDATE && !ui.kNameInput->text().startsWith(QLatin1String("="))) {
-            getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected payees. Payees have been merged."));
+        auto name = ui.kNameInput->text();
+        if (name != NOUPDATE && !name.startsWith(QLatin1String("="))) {
+            // Is this name already existing?
+            bool messageSent = false;
+            SKGPayeeObject p(getDocument());
+            p.setName(name);
+            IFOK(p.load()) {
+                if (selection.indexOf(p) == -1) {
+                    // We will have to merge with the existing payee
+                    selection.insert(0, p);
+                    nb++;
 
-            // Do the merge
-            SKGPayeeObject payeeObj1(selection[0]);
-            for (int i = 1; !err && i < nb; ++i) {
-                SKGPayeeObject payeeObj(selection.at(i));
-
-                // Send message
-                IFOKDO(err, payeeObj.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been merged with payee '%2'", payeeObj1.getDisplayName(), payeeObj.getDisplayName()), SKGDocument::Hidden));
-
-                err = payeeObj1.merge(payeeObj);
+                    getDocument()->sendMessage(i18nc("Information message", "You tried to modify names of selected payees to an existing payee. Payees have been merged."));
+                    messageSent = true;
+                }
             }
 
-            // Change selection for the rest of the operation
-            selection.clear();
-            selection.push_back(payeeObj1);
-            nb = 1;
+            // Is it a massive modification of payees to merge them ?
+            if (nb > 1) {
+                if (!messageSent) {
+                    getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected payees. Payees have been merged."));
+                }
+
+                // Do the merge
+                SKGPayeeObject payeeObj1(selection[0]);
+                for (int i = 1; !err && i < nb; ++i) {
+                    SKGPayeeObject payeeObj(selection.at(i));
+
+                    // Send message
+                    IFOKDO(err, payeeObj.getDocument()->sendMessage(i18nc("An information message", "The payee '%1' has been merged with payee '%2'", payeeObj1.getDisplayName(), payeeObj.getDisplayName()), SKGDocument::Hidden));
+
+                    err = payeeObj1.merge(payeeObj);
+                }
+
+                // Change selection for the rest of the operation
+                selection.clear();
+                selection.push_back(payeeObj1);
+                nb = 1;
+            }
         }
 
         for (int i = 0; !err && i < nb; ++i) {
             // Modification of object
             SKGPayeeObject payee(selection.at(i));
-            err = payee.setName(ui.kNameInput->text());
+            err = payee.setName(name);
             QString address = ui.kAddressEdit->text();
             if (address != NOUPDATE) {
                 IFOKDO(err, payee.setAddress(address))
@@ -277,7 +297,7 @@ void SKGPayeePluginWidget::onModifyPayee()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 
     // Set focus on table
     ui.kView->getView()->setFocus();
