@@ -105,6 +105,15 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument)
     connect(actExecuteAll, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::ALL); });
     registerGlobalAction(QStringLiteral("execute_all"), actExecuteAll, QStringList() << QStringLiteral("rule"), 1, -1, 501);
 
+    // Execute on not checked
+    {
+        QStringList overlaycsv;
+        overlaycsv.push_back(QStringLiteral("document-import"));
+        auto actExecuteImported = new QAction(SKGServices::fromTheme(QStringLiteral("system-run"), overlaycsv), i18nc("Verb, action to execute", "Execute on not checked operations"), this);
+        connect(actExecuteImported, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::NOTCHECKED); });
+        registerGlobalAction(QStringLiteral("execute_notchecked"), actExecuteImported, QStringList() << QStringLiteral("rule"), 1, -1, 502);
+    }
+
     // Execute on imported operation
     {
         QStringList overlaycsv;
@@ -271,7 +280,7 @@ void SKGSearchPlugin::find()
                 xmlsearchcondition = doc.toString();
             } else if (table == QStringLiteral("operation") || table == QStringLiteral("suboperation")) {
                 QStringList attributeForQuery;
-                attributeForQuery << QStringLiteral("d_date") << QStringLiteral("i_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE") << QStringLiteral("t_comment") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_status") << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_ACCOUNT") << QStringLiteral("f_REALCURRENTAMOUNT") << QStringLiteral("t_REALREFUND");
+                attributeForQuery << QStringLiteral("d_date") << QStringLiteral("t_number") << QStringLiteral("t_mode") << QStringLiteral("t_PAYEE") << QStringLiteral("t_comment") << QStringLiteral("t_REALCATEGORY") << QStringLiteral("t_status") << QStringLiteral("t_bookmarked") << QStringLiteral("t_imported") << QStringLiteral("t_ACCOUNT") << QStringLiteral("f_REALCURRENTAMOUNT") << QStringLiteral("t_REALREFUND");
 
                 QDomDocument doc(QStringLiteral("SKGML"));
                 QDomElement element = doc.createElement(QStringLiteral("element"));
@@ -288,7 +297,7 @@ void SKGSearchPlugin::find()
                         op.load();
 
                         QString val = op.getAttribute(attRead);
-                        if (!val.isEmpty() && !(att == QStringLiteral("i_number") && val == QStringLiteral("0"))) {
+                        if (!val.isEmpty()) {
                             QDomElement elementElement = doc.createElement(QStringLiteral("element"));
                             elementLine.appendChild(elementElement);
 
