@@ -40,7 +40,7 @@ tempDir='/data'
 
 class Releasor(object):
     def __init__(self, args):
-        self.ubuntuVersions=['xenial', 'zesty', 'artful', 'bionic']
+        self.ubuntuVersions=['xenial', 'artful', 'bionic']
         self.workdingDir=os.path.join(tempDir, 'skrooge-release_' + args.version)
         print("# Working directory :" + self.workdingDir)    
         if args.version.endswith(".0") or args.stable:
@@ -70,9 +70,11 @@ class Releasor(object):
     def makeTarFile(self, args):
         print('# Make the tar file')
         cmd = ['git', 'clone', 'https://github.com/KDE/releaseme.git']
+        self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
         if rc == 0:
             cmd = ['releaseme/tarme.rb', '--version', args.version, '--origin', 'trunk', 'skrooge']
+            self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             
             shutil.rmtree(os.path.join(self.workdingDir, 'skrooge-'+args.version))
@@ -93,6 +95,7 @@ class Releasor(object):
         tarfile = 'skrooge-'+args.version+'.tar.xz'
         print('#   Untar '+tarfile)
         cmd = ['tar', '-xvf', tarfile]
+        self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
         if rc == 0:
             print('#   Change the CMakeLists.txt')
@@ -108,7 +111,11 @@ class Releasor(object):
                             print('#     SKG_BETA changes to "'+bb+'"')
                             CMakeListsContent += 'SET(SKG_BETA "'+bb+'")\n'              
                         else:
-                            CMakeListsContent += line     
+                            if line.startswith('FEATURE_SUMMARY'):
+                                CMakeListsContent += line
+                                break
+                            else:
+                                CMakeListsContent += line     
             with open(os.path.join(p, 'CMakeLists.txt'), 'w') as fileCMakeLists:
                 fileCMakeLists.write(CMakeListsContent)
             
@@ -117,9 +124,11 @@ class Releasor(object):
             os.mkdir(buildPath)
             os.chdir(buildPath) 
             cmd = ['cmake', '..', '-DCMAKE_INSTALL_PREFIX=`kf5-config --prefix`', '-DQT_PLUGIN_INSTALL_DIR=`kf5-config --qt-plugins`']
+            self.logfile.write('### '+' '.join(cmd)+'\n')
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             if rc == 0:    
                 cmd = ['make', 'splash']
+                self.logfile.write('### '+' '.join(cmd)+'\n')                
                 rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
                 if rc == 0:                   
                     print('#   Create the tar file')
@@ -128,18 +137,23 @@ class Releasor(object):
                     os.remove(tarfile)
                     cmd = ['tar', '-cJf', tarfile, p]
                     rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
+                    self.logfile.write('### '+' '.join(cmd)+'\n')                
                     if rc == 0:
                         cmd = ['gpg2', '--armor', '--detach-sig', '-o', tarfile+'.sig', tarfile]
+                        self.logfile.write('### '+' '.join(cmd)+'\n')                
                         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)                                  
                         if rc == 0:
                             print("Skrooge "+args.version+" released\n\nHi,\n\nCould you publish the following files in skrooge/"+("stable" if args.stable else "unstable")+"?\n")
                             cmd = ['sha256sum', tarfile]
+                            self.logfile.write('### '+' '.join(cmd)+'\n')                
                             rc = subprocess.call(cmd)  
                             if rc == 0:
                                 cmd = ['sha256sum', tarfile+'.sig']
+                                self.logfile.write('### '+' '.join(cmd)+'\n')                
                                 rc = subprocess.call(cmd)  
                             print("Thank you.\nRegards.\n"   )                             
-        shutil.rmtree(p)
+        if rc == 0:
+            shutil.rmtree(p)
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         return rc    
     
@@ -147,6 +161,7 @@ class Releasor(object):
         print('# Get dsc')
         os.chdir(self.workdingDir)  
         cmd = ['apt', 'source', 'skrooge']
+        self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
         if rc == 0:
             previousPackage = [os.path.join(self.workdingDir, o) for o in os.listdir(self.workdingDir) if os.path.isdir(os.path.join(self.workdingDir, o)) and o.startswith('skrooge-')][0]
@@ -156,9 +171,11 @@ class Releasor(object):
             if os.path.exists('debian'):
                 shutil.rmtree('debian')
             cmd = ['tar', '-xvf', os.path.join(toolPath, 'skrooge-release-debian.tar.gz')]
+            self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             if rc == 0:
                 cmd = ['uupdate', '-u', 'skrooge-'+args.version+'.tar.xz']
+                self.logfile.write('### '+' '.join(cmd)+'\n')                
                 rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
                 if rc == 0:
                     # Read the changelog
@@ -171,7 +188,8 @@ class Releasor(object):
                             if line.strip() == '' and done == False:
                                 changelogContent += ' -- Stephane MANKOWSKI (Perso) <stephane@mankowski.fr>  {}\n'.format(datetime.datetime.now().strftime('%a, %d %b %Y %H:%M:%S +0100'))
                                 done = True
-                            changelogContent += line  
+                            if not line.startswith(' -- '):
+                                changelogContent += line  
                         
                         #
                         for ppa in self.ppatotreat:
@@ -197,9 +215,12 @@ class Releasor(object):
                                     fileDebianChangelog.write(changelogContent+'\n')
                                     
                                     cmd = ['debuild', '-S', '-sa']
+                                    self.logfile.write('### '+' '.join(cmd)+'\n')                
                                     rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
                                     if rc!=0:
                                         break
+                            if rc!=0:
+                                break                                    
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         return rc      
     
@@ -211,11 +232,12 @@ class Releasor(object):
         os.chdir(self.workdingDir)  
         for ppa in self.ppatotreat:
             for i in range(len(self.ubuntuVersions)):
-                print('#   {}/{}: {}'.format(i+1, len(self.ubuntuVersions), self.ubuntuVersions[i]))
+                print('#   {}/{}: {} {}'.format(i+1, len(self.ubuntuVersions), self.ubuntuVersions[i], ppa))
                 cmd = ['dput', '-f', 'ppa:s-mankowski/'+ppa+'-kf5', 'skrooge_'+args.version+'-0ubuntu1~'+ppa+str(i+1)+'_source.changes']
                 if not args.publish:
-                    print('#     '+' '.join(cmd))
+                    print('#     '+' '.join(cmd)+'\n')
                 else:
+                    self.logfile.write('### '+' '.join(cmd)+'\n')                
                     rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
                     if rc!=0:
                         break
@@ -230,14 +252,17 @@ class Releasor(object):
         os.chdir(self.workdingDir)  
         cmd = ['kdecp5', 'skrooge-'+args.version+'.tar.xz', 'ftp://upload.kde.org/incoming']
         if not args.publish:
-            print('#     '+' '.join(cmd))
+            print('#     '+' '.join(cmd)+'\n')
         else:
+            self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
             if rc == 0:
+                self.logfile.write('### '+' '.join(cmd)+'\n')                
                 cmd = ['kdecp5', 'skrooge-'+args.version+'.tar.xz.sig', 'ftp://upload.kde.org/incoming']
                 if not args.publish:
-                    print('#     '+' '.join(cmd))
+                    print('#     '+' '.join(cmd)+'\n')
                 else:
+                    self.logfile.write('### '+' '.join(cmd)+'\n')                
                     rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         return rc    
@@ -250,6 +275,7 @@ class Releasor(object):
             os.remove(targteappimage)  
             
         cmd = ['wget', '-c', '-nv', 'https://raw.githubusercontent.com/probonopd/AppImages/master/pkg2appimage']
+        self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
         if rc == 0:
             for line in fileinput.input(['pkg2appimage'], inplace=True):
@@ -262,6 +288,7 @@ class Releasor(object):
                 cmd = ['cp', os.path.join(localPath, 'appimage.yml'), '.']
             else:
                 cmd = ['wget', '-c', '-nv', 'https://cgit.kde.org/skrooge.git/plain/appimage.yml']
+            self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
             if rc == 0:
                 if not args.stable:
@@ -269,6 +296,7 @@ class Releasor(object):
                         print(line.replace('ppa-kf5', 'beta-kf5'), end='')
                     
                 cmd = ['./pkg2appimage', 'appimage.yml']
+                self.logfile.write('### '+' '.join(cmd)+'\n')                
                 rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile) 
                 if rc == 0:                          
                     appimage_file = [os.path.join(self.workdingDir, "out/"+o) for o in os.listdir("./out") if o.endswith('.AppImage')][0]
@@ -289,13 +317,14 @@ class Releasor(object):
             cmd = ['cp', os.path.join(localPath, 'snapcraft.yaml'), '.']
         else:
             cmd = ['wget', '-c', '-nv', 'https://cgit.kde.org/skrooge.git/plain/snapcraft.yaml']
+        self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
         if rc == 0:
-            if not args.stable:
-                for line in fileinput.input(['snapcraft.yaml'], inplace=True):
-                    print(line.replace('version: "X.X.X"', 'version: "'+args.version+'"').replace('source: XXX', 'source: '+localPath if args.fromlocal else 'source: git://anongit.kde.org/skrooge.git'), end='')
+            for line in fileinput.input(['snapcraft.yaml'], inplace=True):
+                print(line.replace('version: "X.X.X"', 'version: "'+args.version+'"').replace('source: XXX', 'source: '+localPath if args.fromlocal else 'source: git://anongit.kde.org/skrooge.git'), end='')
                 
             cmd = ['snapcraft']
+            self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile) 
         print('#   '+("DONE" if rc == 0 else "FAILED"))
         
