@@ -1136,7 +1136,15 @@ bool SKGObjectModel::dropMimeData(const QMimeData* iData,
                 // Send message
                 IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The account '%1' has been merged with account '%2'", child.getDisplayName(), parentAccount.getDisplayName()), SKGDocument::Hidden));
 
-                IFOKDO(err, parentAccount.merge(child))
+                double balancebefore = 0.0;
+                double balanceafter = 0.0;
+                SKGUnitObject unit2;
+                IFOKDO(err, parentAccount.getInitialBalance(balancebefore, unit2))
+                IFOKDO(err, parentAccount.merge(child, !(QApplication::keyboardModifiers() &Qt::ControlModifier)))
+                IFOKDO(err, parentAccount.getInitialBalance(balanceafter, unit2))
+                if (balanceafter != balancebefore) {
+                    getDocument()->sendMessage(i18nc("Warning message", "The initial balance of the target account '%1' has been change to %2.\nIf you want to do the merge without changing the initial balance, you must keep the Ctrl key pressed.", parentAccount.getDisplayName(), balanceafter), SKGDocument::Warning);
+                }
             }
         }
     } else if (iData->hasFormat(QStringLiteral("application/skg.unit.ids"))) {
