@@ -830,6 +830,18 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
             getDocument()->getObjects(QStringLiteral("v_operation"), "rd_account_id=" % SKGServices::intToString(getID()) % " AND t_status!='Y' AND t_template='N' AND t_imported IN ('Y','P') ORDER BY d_date, id", operations);
 
             // Comparison
+            int nb = operations.count();
+            int nbmax = 500;
+            SKGTRACEL(5) << "Nb operations:" << nb << endl;
+            if (nb > nbmax) {
+                SKGTRACEL(5) << "Too many operations (" << nb << ") ==> Reducing the size of the computation" << endl;
+                for (int i = 0; i < nb - nbmax; ++i) {
+                    SKGOperationObject op(operations.at(0));
+                    auto amount = op.getCurrentAmount();
+                    balance += amount;
+                    operations.removeFirst();
+                }
+            }
             output = getPossibleReconciliations(operations, balance, iTargetBalance, unit1, iSearchAllPossibleReconciliation);
         }
     }
@@ -1004,7 +1016,7 @@ SKGError SKGAccountObject::autoReconcile(double iBalance)
     return err;
 }
 
-SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
+SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount, bool iMergeInitalBalance)
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
@@ -1016,7 +1028,9 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
 
     double balance2 = 0.0;
     SKGUnitObject unit2;
-    IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
+    if (iMergeInitalBalance) {
+        IFOKDO(err, const_cast<SKGAccountObject*>(&iAccount)->getInitialBalance(balance2, unit2))
+    }
 
     // Transfert operations
     SKGObjectBase::SKGListSKGObjectBase ops;
@@ -1033,7 +1047,7 @@ SKGError SKGAccountObject::merge(const SKGAccountObject& iAccount)
     if (!unit1.exist()) {
         unit = unit2;
     }
-    if (unit.exist()) {
+    if (unit.exist() && balance2 != 0.0) {
         double balance = balance1 + SKGUnitObject::convert(balance2, unit2, unit);
         IFOKDO(err, setInitialBalance(balance, unit))
     }
