@@ -115,7 +115,7 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
     SKGTRACEINFUNCRC(10, err);
     if (m_defaultAccount == nullptr && m_document) {
         QFileInfo fInfo(getLocalFileName());
-        QStringList items = fInfo.baseName().split('@');
+        QStringList items = fInfo.completeBaseName().split('@');
         QString bankname;
         QString number;
         QString nameComplete;
@@ -394,6 +394,7 @@ SKGError SKGImportExportManager::finalizeImportation()
                 auto act = m_AccountToCheck.at(i).first;
                 auto targetBalance = m_AccountToCheck.at(i).second;
                 err = act.setAttribute(QStringLiteral("f_importbalance"), SKGServices::doubleToString(targetBalance));
+                IFOKDO(err, act.setAttribute(QStringLiteral("d_importdate"), SKGServices::dateToSqlString(QDate::currentDate())));
                 IFOKDO(err, act.save());
 
                 auto soluces = act.getPossibleReconciliations(targetBalance, false);
