@@ -25,6 +25,7 @@
 #include <qlineedit.h>
 
 #include "skgsortfilterproxymodel.h"
+#include "skgobjectmodelbase.h"
 #include "skgmainpanel.h"
 
 SKGFilteredTableView::SKGFilteredTableView(QWidget* iParent)
@@ -236,4 +237,3 @@ void SKGFilteredTableView::onTextFilterChanged(const QString& iFilter)
         ui.kFilterEdit->setToolTip(tooltip);
     }
 }
-#include "skgfilteredtableview.moc"
