@@ -25,9 +25,9 @@
 
 #include "ui_skgfilteredtableview.h"
 #include "skgbasegui_export.h"
-#include "skgobjectmodelbase.h"
 
 class SKGShow;
+class SKGObjectModelBase;
 
 /**
  * This file is a filetered SKGTableView
