@@ -91,9 +91,9 @@ public:
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
-     * @return true if the arguments have been processed
+     * @return the rest of arguments to treat
      */
-    virtual bool processArguments(const QStringList& iArgument);
+    virtual QStringList processArguments(const QStringList& iArgument);
 
     /**
      * Must be modified to close properly the plugin.
