@@ -317,7 +317,13 @@ void SKGObjectModelBase::refresh()
             // Initialize object to treat
             QString currentGroup;
             int currentGoupId = 0;
-            bool groupByDate = (m_groupby.startsWith(QLatin1String("d_")));
+            bool groupByDate = (m_groupby.startsWith(QLatin1String("d_")) &&
+                                m_groupby != QLatin1String("d_DATEWEEK") &&
+                                m_groupby != QLatin1String("d_DATEMONTH") &&
+                                m_groupby != QLatin1String("d_DATEQUARTER") &&
+                                m_groupby != QLatin1String("d_DATESEMESTER") &&
+                                m_groupby != QLatin1String("d_DATEYEAR"));
+
             bool groupByNum = (m_groupby.startsWith(QLatin1String("f_")) || m_groupby.startsWith(QLatin1String("i_")));
             int nb = m_listObjects.count();
             SKGTRACEL(1) << nb << " objects found" << endl;
