@@ -96,9 +96,22 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
             d->m_current = newCol;
         }
 
+        // Special sort order
+        if (d->m_current != -1) {
+            auto columname = model->getAttribute(d->m_current);
+            if (columname.startsWith(QStringLiteral("f_BALANCE"))) {
+                auto d_date_index = model->getIndexAttribute(QStringLiteral("d_date"));
+                if (d_date_index != -1) {
+                    d->m_current = d_date_index;
+                    d->m_previous = -1;
+                    SKGTRACEL(5) << "SKGSortFilterProxyModel::lessThan-Special sort order on " << columname << endl;
+                }
+            }
+        }
+
         // Comparison
-        QVariant leftData = model->data(left, Qt::UserRole);
-        QVariant rightData = model->data(right, Qt::UserRole);
+        QVariant leftData = model->data(model->index(left.row(), d->m_current, left.parent()), Qt::UserRole);
+        QVariant rightData = model->data(model->index(right.row(), d->m_current, right.parent()), Qt::UserRole);
         SKGObjectBase* leftObj = model->getObjectPointer(left);
         if (leftData == rightData && leftObj) {
             if (leftObj->getTable().isEmpty() && d->m_current != 0) {
@@ -108,16 +121,14 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
                 d->m_insubsort = false;
                 return test;
             }
-            if (leftData.userType() != QVariant::Date &&
-                leftData.userType() != QVariant::DateTime &&
-                leftData.userType() != QVariant::Time) {
-                // Compare on previous column
-                if (!d->m_insubsort && d->m_previous != -1) {
-                    d->m_insubsort = true;
-                    bool test = QSortFilterProxyModel::lessThan(model->index(left.row(), d->m_previous), model->index(right.row(), d->m_previous));
-                    d->m_insubsort = false;
-                    return test;
-                }
+            // Compare on previous column
+            if (!d->m_insubsort && d->m_previous != -1) {
+                d->m_insubsort = true;
+                auto vl = model->index(left.row(), d->m_previous, left.parent());
+                auto vr = model->index(right.row(), d->m_previous, right.parent());
+                bool test = QSortFilterProxyModel::lessThan(vl, vr);
+                d->m_insubsort = false;
+                return test;
             }
 
             // Compare on ID for stability
