@@ -25,7 +25,11 @@
 #include <klocalizedstring.h>
 
 #include <qwidget.h>
+#ifdef SKG_WEBENGINE
+#include <qwebengineview.h>
+#else
 #include <qwebview.h>
+#endif
 #include <qmath.h>
 
 #include <math.h>
@@ -161,12 +165,14 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
                     int conf = KMessageBox::Yes;
                     KMessageBox::ButtonCode button;
                     SKGTRACEL(10) << (KMessageBox::shouldBeShownYesNo(QStringLiteral("updateBookmarkOnClose"), button) ? "updateBookmarkOnClose: Ask confirmation" : "updateBookmarkOnClose: Do not ask confirmation") << endl;
-                    if (iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
-                                i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
-                                i18nc("Question", "Bookmark has been modified"),
-                                KStandardGuiItem::yes(),
-                                KStandardGuiItem::no(),
-                                QStringLiteral("updateBookmarkOnClose"));
+                    if (iUserConfirmation && !oldState.isEmpty()) {
+                        conf = KMessageBox::questionYesNo(this,
+                                                          i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
+                                                          i18nc("Question", "Bookmark has been modified"),
+                                                          KStandardGuiItem::yes(),
+                                                          KStandardGuiItem::no(),
+                                                          QStringLiteral("updateBookmarkOnClose"));
+                    }
                     QApplication::restoreOverrideCursor();
                     if (conf == KMessageBox::Yes) {
                         SKGError err;
@@ -198,12 +204,14 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
                 KMessageBox::ButtonCode button;
                 SKGTRACEL(10) << (KMessageBox::shouldBeShownYesNo(QStringLiteral("updateContextOnClose"), button) ? "updateBookmarkOnClose: Ask confirmation" : "updateBookmarkOnClose: Do not ask confirmation") << endl;
 
-                if (iUserConfirmation && !oldState.isEmpty()) conf = KMessageBox::questionYesNo(this,
-                            i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
-                            i18nc("Question", "Page has been modified"),
-                            KStandardGuiItem::yes(),
-                            KStandardGuiItem::no(),
-                            QStringLiteral("updateContextOnClose"));
+                if (iUserConfirmation && !oldState.isEmpty()) {
+                    conf = KMessageBox::questionYesNo(this,
+                                                      i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
+                                                      i18nc("Question", "Page has been modified"),
+                                                      KStandardGuiItem::yes(),
+                                                      KStandardGuiItem::no(),
+                                                      QStringLiteral("updateContextOnClose"));
+                }
                 QApplication::restoreOverrideCursor();
                 if (conf == KMessageBox::Yes) {
                     SKGError err;
@@ -251,7 +259,12 @@ void SKGTabPage::setZoomPosition(int iValue)
     if (treeView) {
         treeView->setZoomPosition(iValue);
     } else {
-        QWebView* webView = qobject_cast<QWebView*>(widget);
+#ifdef SKG_WEBENGINE
+        auto webView = qobject_cast<QWebEngineView*>(widget);
+#else
+        auto webView = qobject_cast<QWebView*>(widget);
+#endif
+
         if (webView) {
             webView->setZoomFactor(qPow(10, static_cast<qreal>(iValue) / 30.0));
         } else {
@@ -276,7 +289,11 @@ int SKGTabPage::zoomPosition()
     if (treeView) {
         output = treeView->zoomPosition();
     } else {
-        QWebView* webView = qobject_cast<QWebView*>(widget);
+#ifdef SKG_WEBENGINE
+        auto webView = qobject_cast<QWebEngineView*>(widget);
+#else
+        auto webView = qobject_cast<QWebView*>(widget);
+#endif
         if (webView) {
             output = qRound(30.0 * log10(webView->zoomFactor()));
         } else if (widget) {
