@@ -216,7 +216,7 @@ QString SKGTreeView::getState()
 
         // Memorize expanded groups
         if (!m_groupby.isEmpty()) {
-            root.setAttribute(QStringLiteral("expandedGroups"), SKGServices::stringsToCsv(m_expandedNodes));
+            root.setAttribute(QStringLiteral("expandedGroups"), m_expandedNodes.join(QStringLiteral(";")));
         }
     }
     root.setAttribute(QStringLiteral("alternatingRowColors"), alternatingRowColors() ? QStringLiteral("Y") : QStringLiteral("N"));
@@ -230,7 +230,7 @@ QString SKGTreeView::getState()
     if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
         root.setAttribute(QStringLiteral("stickV"), QStringLiteral("Y"));
     }
-    return doc.toString();
+    return doc.toString(-1);
 }
 
 void SKGTreeView::setState(const QString& iState)
@@ -671,6 +671,7 @@ void SKGTreeView::groupByChanged(QAction* iAction)
         m_model->refresh();
 
         refreshExpandCollapse();
+        respanFirstColumns();
     }
 }
 
@@ -826,35 +827,29 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
             if (nbRows) {
                 // Expand nodes
                 bool previousForThis = this->blockSignals(true);
-                for (const auto& exp : qAsConst(m_expandedNodes)) {
-                    for (int i = 0; i < nbRows; ++i) {
-                        QModelIndex index = items.at(i);
-                        SKGObjectBase obj = m_model->getObject(index);
-                        if (obj.getUniqueID() == exp) {
-                            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
-                            setExpanded(idxs, true);
-                            break;
-                        }
+                for (int i = 0; i < nbRows; ++i) {
+                    QModelIndex index = items.at(i);
+                    SKGObjectBase obj = m_model->getObject(index);
+                    if (m_expandedNodes.contains(obj.getUniqueID())) {
+                        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
+                        setExpanded(idxs, true);
                     }
                 }
                 this->blockSignals(previousForThis);
 
                 // Set selection
                 bool focusDone = false;
-                for (const auto& sel : qAsConst(iUniqueIDs)) {
-                    for (int i = 0; i < nbRows; ++i) {
-                        QModelIndex index = items.at(i);
-                        SKGObjectBase obj = m_model->getObject(index);
-                        if (obj.getUniqueID() == sel) {
-                            QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
-                            selModel->select(idxs, QItemSelectionModel::Select | QItemSelectionModel::Rows);
-                            selModel->setCurrentIndex(idxs, QItemSelectionModel::NoUpdate);
-                            ++nbset;
-                            if (iFocusOnFirstOne && !focusDone) {
-                                scrollTo(idxs);
-                                focusDone = true;
-                            }
-                            break;
+                for (int i = 0; i < nbRows; ++i) {
+                    QModelIndex index = items.at(i);
+                    SKGObjectBase obj = m_model->getObject(index);
+                    if (iUniqueIDs.contains(obj.getUniqueID())) {
+                        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
+                        selModel->select(idxs, QItemSelectionModel::Select | QItemSelectionModel::Rows);
+                        selModel->setCurrentIndex(idxs, QItemSelectionModel::NoUpdate);
+                        ++nbset;
+                        if (iFocusOnFirstOne && !focusDone) {
+                            scrollTo(idxs);
+                            focusDone = true;
                         }
                     }
                 }
@@ -1357,6 +1352,7 @@ void SKGTreeView::setModel(QAbstractItemModel* iModel)
         if (m_model) {
             connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::setupHeaderMenu);
             connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::onSelectionChanged);
+            connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::respanFirstColumns, Qt::QueuedConnection);
         }
         QTreeView::setModel(iModel);
 
