@@ -36,7 +36,7 @@ class SKGBASEGUI_EXPORT SKGWidgetSelector : public QWidget
     /**
      * The selected mode
      */
-    Q_PROPERTY(int selectedMode READ getSelectedMode WRITE setSelectedMode USER true)
+    Q_PROPERTY(int selectedMode READ getSelectedMode WRITE setSelectedMode NOTIFY selectedModeChanged USER true)
 
     /**
      * The default mode
@@ -59,7 +59,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGWidgetSelector();
+    ~SKGWidgetSelector() override;
 
     /**
      * Add a button to the selector
