@@ -469,6 +469,31 @@ int main(int argc, char** argv)
             SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-10"));
         }
     }
+
+
+    {
+        // Avoid merge of account due to same name
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_WEBOOB"), err);
+
+            SKGTESTBOOL("PUTENV.weboob", qputenv("PATH", (in + "/skgtestimportbackend/double/:" + path).toLatin1()), true);
+
+            SKGImportExportManager imp1(&document1, QUrl(QStringLiteral(".weboob")));
+            SKGTESTERROR(QStringLiteral("WEBOOB.importFile"), imp1.importFile(), true);
+        }
+
+        // Checks
+        {
+            SKGAccountObject account;
+            SKGTESTERROR(QStringLiteral("ACCOUNT.getObjectByName"), SKGNamedObject::getObjectByName(&document1, QStringLiteral("v_account"), QStringLiteral("CPT"), account), true);
+            SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true);
+            SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-100"));
+        }
+    }
     // End test
     SKGENDTEST();
 }
