@@ -195,11 +195,17 @@ void test_conversions(int& nberror, int& nbcheck, bool showonlyfailures)
 
 void test_nbWorkingDays(int& nberror, int& nbcheck, bool showonlyfailures)
 {
-    SKGTEST(QStringLiteral("DATE:nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 3), QDate(2010, 9, 6)), 1);
-    SKGTEST(QStringLiteral("DATE:nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 6), QDate(2010, 9, 3)), 1);
-    SKGTEST(QStringLiteral("DATE:nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 3), QDate(2010, 9, 3)), 1);
-    SKGTEST(QStringLiteral("DATE:nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 1), QDate(2010, 9, 3)), 2);
-    SKGTEST(QStringLiteral("DATE:nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 1), QDate(2010, 9, 8)), 5);
+    SKGTEST(QStringLiteral("SKGServices::nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 3), QDate(2010, 9, 6)), 1);
+    SKGTEST(QStringLiteral("SKGServices::nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 6), QDate(2010, 9, 3)), 1);
+    SKGTEST(QStringLiteral("SKGServices::nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 3), QDate(2010, 9, 3)), 1);
+    SKGTEST(QStringLiteral("SKGServices::nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 1), QDate(2010, 9, 3)), 2);
+    SKGTEST(QStringLiteral("SKGServices::nbWorkingDays"), SKGServices::nbWorkingDays(QDate(2010, 9, 1), QDate(2010, 9, 8)), 5);
+}
+
+void test_getnext(int& nberror, int& nbcheck, bool showonlyfailures)
+{
+    SKGTEST(QStringLiteral("SKGServices::getNextString"), SKGServices::getNextString(QStringLiteral("12345")), QStringLiteral("12346"));
+    SKGTEST(QStringLiteral("SKGServices::getNextString"), SKGServices::getNextString(QStringLiteral("9")), QStringLiteral("10"));
 }
 
 void test_errors(int& nberror, int& nbcheck, bool showonlyfailures)
@@ -604,6 +610,11 @@ void test_stringToSearchCriterias(int& nberror, int& nbcheck, bool showonlyfailu
                     QStringList() << QStringLiteral("t_comment"), nullptr),
             QStringLiteral("((lower(t_comment) LIKE '%%')) AND NOT((lower(t_comment) LIKE '%v5%'))"));
 
+    SKGTEST(QStringLiteral("STR:searchCriteriasToWhereClause"),
+            SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(QStringLiteral("a'b")),
+                    QStringList() << QStringLiteral("t_comment"), nullptr),
+            QStringLiteral("((lower(t_comment) LIKE '%a''b%'))"));
+
     SKGTEST(QStringLiteral("STR:searchCriteriasToWhereClause"),
             SKGServices::searchCriteriasToWhereClause(SKGServices::stringToSearchCriterias(QStringLiteral("-v5")),
                     QStringList() << QStringLiteral("t_comment"), nullptr, true),
@@ -676,6 +687,8 @@ int main(int argc, char** argv)
 
         test_stringToSearchCriterias(nberror, nbcheck, showonlyfailures);
 
+        test_getnext(nberror, nbcheck, showonlyfailures);
+
         // Various test
         SKGStringListList table;
         table.push_back(QStringList() << QStringLiteral("Person") << QStringLiteral("Salary") << QStringLiteral("Age"));
